@@ -43,7 +43,7 @@
     </message>
     <message>
         <location filename="../mxcodecs.ui" line="97"/>
-        <location filename="../mxcodecs.cpp" line="256"/>
+        <location filename="../mxcodecs.cpp" line="270"/>
         <source>Cancel</source>
         <translation>Cancelar</translation>
     </message>
@@ -93,129 +93,139 @@
         <translation>Alt+H</translation>
     </message>
     <message>
-        <location filename="../mxcodecs.cpp" line="113"/>
-        <location filename="../mxcodecs.cpp" line="120"/>
-        <location filename="../mxcodecs.cpp" line="128"/>
+        <location filename="../mxcodecs.cpp" line="103"/>
+        <location filename="../mxcodecs.cpp" line="110"/>
+        <location filename="../mxcodecs.cpp" line="118"/>
+        <location filename="../mxcodecs.cpp" line="126"/>
         <location filename="../mxcodecs.cpp" line="135"/>
-        <location filename="../mxcodecs.cpp" line="143"/>
-        <location filename="../mxcodecs.cpp" line="150"/>
+        <location filename="../mxcodecs.cpp" line="142"/>
+        <location filename="../mxcodecs.cpp" line="151"/>
         <location filename="../mxcodecs.cpp" line="159"/>
-        <location filename="../mxcodecs.cpp" line="166"/>
         <source>&lt;b&gt;Running command...&lt;/b&gt;&lt;p&gt;</source>
         <translation>
 &lt;b&gt;A executar o comando...&lt;/b&gt;&lt;p&gt;</translation>
     </message>
     <message>
-        <location filename="../mxcodecs.cpp" line="116"/>
-        <location filename="../mxcodecs.cpp" line="131"/>
-        <location filename="../mxcodecs.cpp" line="137"/>
-        <location filename="../mxcodecs.cpp" line="146"/>
-        <location filename="../mxcodecs.cpp" line="152"/>
+        <location filename="../mxcodecs.cpp" line="106"/>
+        <location filename="../mxcodecs.cpp" line="122"/>
+        <location filename="../mxcodecs.cpp" line="129"/>
+        <location filename="../mxcodecs.cpp" line="138"/>
+        <location filename="../mxcodecs.cpp" line="144"/>
+        <location filename="../mxcodecs.cpp" line="155"/>
         <location filename="../mxcodecs.cpp" line="162"/>
-        <location filename="../mxcodecs.cpp" line="168"/>
-        <location filename="../mxcodecs.cpp" line="197"/>
-        <location filename="../mxcodecs.cpp" line="233"/>
+        <location filename="../mxcodecs.cpp" line="194"/>
+        <location filename="../mxcodecs.cpp" line="247"/>
         <source>Error</source>
         <translation>Erro</translation>
     </message>
     <message>
-        <location filename="../mxcodecs.cpp" line="117"/>
-        <location filename="../mxcodecs.cpp" line="132"/>
-        <location filename="../mxcodecs.cpp" line="147"/>
-        <location filename="../mxcodecs.cpp" line="163"/>
+        <location filename="../mxcodecs.cpp" line="107"/>
+        <location filename="../mxcodecs.cpp" line="123"/>
+        <location filename="../mxcodecs.cpp" line="139"/>
+        <location filename="../mxcodecs.cpp" line="156"/>
         <source>Cannot connect to the download site</source>
         <translation>O computador não se consegue ligar ao sítio </translation>
     </message>
     <message>
-        <location filename="../mxcodecs.cpp" line="123"/>
-        <location filename="../mxcodecs.cpp" line="138"/>
-        <location filename="../mxcodecs.cpp" line="153"/>
-        <location filename="../mxcodecs.cpp" line="169"/>
+        <location filename="../mxcodecs.cpp" line="113"/>
+        <location filename="../mxcodecs.cpp" line="130"/>
+        <location filename="../mxcodecs.cpp" line="145"/>
+        <location filename="../mxcodecs.cpp" line="163"/>
         <source>Error downloading %1</source>
         <translation>Erro ao transferir %1</translation>
     </message>
     <message>
-        <location filename="../mxcodecs.cpp" line="174"/>
+        <location filename="../mxcodecs.cpp" line="168"/>
         <source>&lt;b&gt;Download Finished.&lt;/b&gt;</source>
         <translation>&lt;b&gt;Transferência terminada.&lt;/b&gt;</translation>
     </message>
     <message>
-        <location filename="../mxcodecs.cpp" line="193"/>
+        <location filename="../mxcodecs.cpp" line="190"/>
         <source>Installing downloaded files</source>
         <translation>A instalar os ficheiros transferidos</translation>
     </message>
     <message>
-        <location filename="../mxcodecs.cpp" line="198"/>
+        <location filename="../mxcodecs.cpp" line="195"/>
         <source>No downloaded *.debs files found.</source>
         <translation>Não são encontrados ficheiros *.debs transferidos</translation>
     </message>
     <message>
-        <location filename="../mxcodecs.cpp" line="211"/>
+        <location filename="../mxcodecs.cpp" line="208"/>
         <source>&lt;b&gt;Installing...&lt;/b&gt;&lt;p&gt;</source>
         <translation>&lt;b&gt;A instalar...&lt;/b&gt;&lt;p&gt;</translation>
     </message>
     <message>
-        <location filename="../mxcodecs.cpp" line="215"/>
+        <location filename="../mxcodecs.cpp" line="222"/>
         <source>Error installing %1</source>
         <translation>Erro ao instalar %1</translation>
     </message>
     <message>
         <location filename="../mxcodecs.cpp" line="226"/>
+        <source>Fix missing dependencies...</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../mxcodecs.cpp" line="228"/>
+        <source>Error running &apos;apt-get -fm install&apos; command</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../mxcodecs.cpp" line="240"/>
         <source>&lt;b&gt;Installation process has finished&lt;/b&gt;</source>
         <translation>&lt;b&gt;O processo de instalação terminou&lt;/b&gt;</translation>
     </message>
     <message>
-        <location filename="../mxcodecs.cpp" line="229"/>
+        <location filename="../mxcodecs.cpp" line="243"/>
         <source>Finished</source>
         <translation>Terminado</translation>
     </message>
     <message>
-        <location filename="../mxcodecs.cpp" line="230"/>
+        <location filename="../mxcodecs.cpp" line="244"/>
         <source>Codecs files have been downloaded and installed successfully.</source>
         <translation>Os ficheiros dos codecs foram transferidos e instalados com êxito.</translation>
     </message>
     <message>
-        <location filename="../mxcodecs.cpp" line="234"/>
+        <location filename="../mxcodecs.cpp" line="248"/>
         <source>Process finished. Errors have occurred during the installation.</source>
         <translation>Processo terminado. Ocorreram erros durante a instalação.</translation>
     </message>
     <message>
-        <location filename="../mxcodecs.cpp" line="249"/>
+        <location filename="../mxcodecs.cpp" line="263"/>
         <source>About MX Codecs</source>
         <translation>Sobre o MX_Instalador de Codecs</translation>
     </message>
     <message>
-        <location filename="../mxcodecs.cpp" line="250"/>
+        <location filename="../mxcodecs.cpp" line="264"/>
         <source>MX Codecs</source>
         <translation>MX_Instalador de Codecs</translation>
     </message>
     <message>
-        <location filename="../mxcodecs.cpp" line="250"/>
+        <location filename="../mxcodecs.cpp" line="264"/>
         <source>Version: </source>
         <translation>Versão:</translation>
     </message>
     <message>
-        <location filename="../mxcodecs.cpp" line="252"/>
+        <location filename="../mxcodecs.cpp" line="266"/>
         <source>Simple codecs downloader for MX Linux</source>
         <translation>Programa simples de transferência de codecs para o Linux MX</translation>
     </message>
     <message>
-        <location filename="../mxcodecs.cpp" line="253"/>
+        <location filename="../mxcodecs.cpp" line="267"/>
         <source>Copyright (c) MX Linux</source>
         <translation>Copyright (c) MX Linux</translation>
     </message>
     <message>
-        <location filename="../mxcodecs.cpp" line="254"/>
+        <location filename="../mxcodecs.cpp" line="268"/>
         <source>License</source>
         <translation>Licença</translation>
     </message>
     <message>
-        <location filename="../mxcodecs.cpp" line="255"/>
+        <location filename="../mxcodecs.cpp" line="269"/>
         <source>Changelog</source>
         <translation>Registo de alterações</translation>
     </message>
     <message>
-        <location filename="../mxcodecs.cpp" line="271"/>
+        <location filename="../mxcodecs.cpp" line="285"/>
         <source>&amp;Close</source>
         <translation>&amp;Fechar</translation>
     </message>
